==> RsCMX_Signaling-4.0.120-py3-none-any.whl: RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/Timing/SfnOffset.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfnOffsetCls:
	"""SfnOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfnOffset", core, parent)

	def set(self, cell_name: str, sfn_offset: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:TIMing:SFNoffset \n
		Snippet: driver.configure.signaling.nradio.cell.timing.sfnOffset.set(cell_name = '1', sfn_offset = 1) \n
		Defines a system frame number offset. \n
			:param cell_name: No help available
			:param sfn_offset: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('sfn_offset', sfn_offset, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:TIMing:SFNoffset {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:TIMing:SFNoffset \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.timing.sfnOffset.get(cell_name = '1') \n
		Defines a system frame number offset. \n
			:param cell_name: No help available
			:return: sfn_offset: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:TIMing:SFNoffset? {param}')
		return Conversions.str_to_int(response)

==> RsCMX_Signaling-7.40.0-py3-none-any.whl: RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/Timing/SfnOffset.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfnOffsetCls:
	"""SfnOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfnOffset", core, parent)

	def set(self, cell_name: str, sfn_offset: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:TIMing:SFNoffset \n
		Snippet: driver.configure.signaling.nradio.cell.timing.sfnOffset.set(cell_name = '1', sfn_offset = 1) \n
		Defines a system frame number offset for a cell, before switching it on. \n
			:param cell_name: No help available
			:param sfn_offset: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('sfn_offset', sfn_offset, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:TIMing:SFNoffset {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:TIMing:SFNoffset \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.timing.sfnOffset.get(cell_name = '1') \n
		Defines a system frame number offset for a cell, before switching it on. \n
			:param cell_name: No help available
			:return: sfn_offset: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:TIMing:SFNoffset? {param}')
		return Conversions.str_to_int(response)
